@@ -5,6 +5,9 @@ from ai_kit.core.llms.litellm_client import StructuredOutputClient
 from ai_kit.utils.prompts import load_prompt
 from ai_kit.config import CoreConfig
 from ai_kit.utils.fs import package_root
+import os
+import json
+from ai_kit.utils.fs import find_workspace_root
 
 logger = logging.getLogger(__name__)
 
@@ -15,12 +18,14 @@ ROUTER_PROMPT_PATH = f"{PACKAGE_ROOT}/system_prompts/router.md"
 # 1. DEFINE A SINGLE ROUTE
 # -----------------------------
 
+
 class RouteDefinition(BaseModel):
     """
     Defines an available route:
     - name (unique identifier)
     - description (what the route is used for)
     """
+
     name: str
     description: str
 
@@ -29,11 +34,13 @@ class RouteDefinition(BaseModel):
 # 2. MANAGE A REGISTRY OF ROUTES
 # -----------------------------
 
+
 class RouteRegistry:
     """
     Manages a collection of RouteDefinition objects.
     You can register new routes and build a prompt snippet.
     """
+
     def __init__(self):
         self._routes: Dict[str, RouteDefinition] = {}
 
@@ -71,10 +78,12 @@ class RouteRegistry:
 # 3. ROUTING DECISION MODEL
 # -----------------------------
 
+
 class RoutingDecision(BaseModel):
     """
     The structured output from the model indicating which route to use.
     """
+
     route: str = Field(..., description="The chosen route name")
     confidence: float = Field(..., description="Confidence from 0.0 to 1.0")
     reasoning: str = Field(..., description="Brief explanation of the choice")
@@ -84,16 +93,32 @@ class RoutingDecision(BaseModel):
 # 4. THE ROUTER
 # -----------------------------
 
+# llama-3.1-8B-instruct is much faster than gpt-4o
+# gpt-4o: 2.79, 1.87
+# llama-3.1-8B-instruct: 0.92, 0.87
+
+
 class Router:
-    def __init__(self, route_registry: RouteRegistry, model: str = "gpt-4o"):
+    def __init__(
+        self, route_registry: RouteRegistry, model: Optional[str] = None
+    ):
         """
-        :param llm_client: An LLM client capable of structured output completion.
-                           e.g. a wrapper around GPT-4 with a method:
-                               structured_output_completion(messages, output_schema)
         :param route_registry: The registry containing all valid routes.
+        :param model: Optional model name. If not provided, load from config.json.
         """
-        self.client = StructuredOutputClient(model=model)
         self.registry = route_registry
+        
+        # Try to load model from config if not provided
+        if model is None:
+            try:
+                config = UserConfig.load_config()
+                model = config.get("router", {}).get("default_model", "llama-3.3-70b-versatile")
+            except Exception as e:
+                logger.warning(f"Failed to load router default model from config.json: {e}")
+                model = "llama-3.3-70b-versatile"  # Fallback to default
+        
+        self.model = model
+        self.client = StructuredOutputClient(model=model)
 
     def get_system_prompt(self) -> str:
         """
@@ -115,19 +140,21 @@ class Router:
         4. Optional fallback logic if route is unrecognized or confidence is too low.
         """
         system_prompt = self.get_system_prompt()
-
+        messages = [
+            {"role": "system", "content": system_prompt},
+            {"role": "user", "content": system_prompt + "\n\n" + query},
+        ]
         # Call the LLM client with a structured output request
         decision = self.client.structured_output_completion(
-            messages=[
-                {"role": "system", "content": system_prompt},
-                {"role": "user", "content": query},
-            ],
+            messages=messages,
             schema=RoutingDecision,
         )
 
         # Fallback check: if the chosen route is not in the registry, or low confidence
         if decision.route not in self.registry.route_names:
-            logger.warning(f"Unrecognized route chosen: {decision.route}. Falling back to default.")
+            logger.warning(
+                f"Unrecognized route chosen: {decision.route}. Falling back to default."
+            )
             # You can decide a default fallback
             decision.route = "thinking_agent"
             decision.reasoning += " [FELL BACK due to invalid route]"
@@ -141,4 +168,4 @@ class Router:
             # but note the low confidence in logs.
             pass
 
-        return decision
\ No newline at end of file
+        return decision
